Crate gabelang

Crate gabelang 

Modules

evaluator
The evaluator module contains the GabrEnv struct which provides an environment in order to run gabelang code
lexer
The lexer module contains the Lexer struct which creates an iterator of tokens that may be used by the gabelang parser when given a string
parser
The parser module contains the Parser struct which contains a lexer and creates an AST(Abstract Syntax Tree) when given a string
repl
The repl module contains a start function run an isolated instance of the gabelang repl

Structs

Config
Config for running the gabelang interpretter
Gabelang
Wasm Interpretter Binding for the gabelang language

Functions

run
Runs the gabelang interpretter by taking in a config and either running the repl or interpretting a .gabe file based on args