pub fn run(config: Config) -> Result<()>Expand description
Runs the gabelang interpretter by taking in a config and either running the repl or interpretting a .gabe file based on args
Config can be generated using gabelang::Config::build
Errors
run can only generate errors if it is interpretting a file and either the file fails
Example
use gabelang::Config;
gabelang::run(Config::default()).expect("Application ran into an unexpected error");